==> totvs-log-web-foundation-0.0.9.tgz: package/src/lib/services/message/message.component.ts <==
import { ShowMessageLinkActionType } from 'totvs-log-base-foundation';
import { ThfModalComponent } from '@totvs/thf-ui';
import { Component, ViewChild } from '@angular/core';

/**
 * Classe/componente de mensagem
 */
@Component({
    selector: 'lib-message',
    templateUrl: './message.component.html',
    styleUrls: ['./message.component.css']
})
export class MessageComponent {

    /**
     * Atributo que recebe a referência do componente ThfModalComponent no HTML
     */
    @ViewChild(ThfModalComponent, {static: true}) thfModal: ThfModalComponent;

    /**
     * Atributo com o título da mensagem
     */
    messageTitle = '';

    /**
     * Atributo com o texto da mensagem
     */
    messageText = '';

    /**
     * Atributo com os detalhes da mensagem
     */
    messageDetails = '';

    /**
     * Atributo que recebe a ação de confirmação
     */
    messageConfirmAction = undefined;

    /**
     * Atributo que recebe a ação de cancelamento
     */
    messageCancelAction = undefined;

    /**
     * Atributo que recebe o tipo do link
     */
    messageLinkActionType = ShowMessageLinkActionType.No;

    /**
     * Atributo que recebe o link
     */
    messageLinkAction = undefined;

    /**
     * Atributo que recebe o label do link
     */
    messageLinkLabel = '';

    /**
     * Atributo que indica se os detalhes da mensagem devem ser escondidos
     */
    hideDetails = true;

    /**
     * Método responsável por disparar a abertura da dialog
     */
    public openDialog() {
        this.thfModal.open();
    }

    /**
     * Método responsável por fechar a dialog
     */
    public closeDialog() {
        this.thfModal.close();
    }

    /**
     * Método responsável por executar ação do link relacionado a mensagem
     */
    public linkAction() {

        this.messageLinkAction();
    }
}

==> totvs-log-web-foundation-1.0.0.tgz: package/src/lib/services/message/message.component.ts <==
import { ShowMessageLinkActionType } from 'totvs-log-base-foundation';
import { PoModalComponent } from '@portinari/portinari-ui';
import { Component, ViewChild } from '@angular/core';

/**
 * Classe/componente de mensagem
 */
@Component({
    selector: 'lib-message',
    templateUrl: './message.component.html',
    styleUrls: ['./message.component.css']
})
export class MessageComponent {

    /**
     * Atributo que recebe a referência do componente PoModalComponent no HTML
     */
    @ViewChild(PoModalComponent, {static: true}) poModal: PoModalComponent;

    /**
     * Atributo com o título da mensagem
     */
    messageTitle = '';

    /**
     * Atributo com o texto da mensagem
     */
    messageText = '';

    /**
     * Atributo com os detalhes da mensagem
     */
    messageDetails = '';

    /**
     * Atributo que recebe a ação de confirmação
     */
    messageConfirmAction = undefined;

    /**
     * Atributo que recebe a ação de cancelamento
     */
    messageCancelAction = undefined;

    /**
     * Atributo que recebe o tipo do link
     */
    messageLinkActionType = ShowMessageLinkActionType.No;

    /**
     * Atributo que recebe o link
     */
    messageLinkAction = undefined;

    /**
     * Atributo que recebe o label do link
     */
    messageLinkLabel = '';

    /**
     * Atributo que indica se os detalhes da mensagem devem ser escondidos
     */
    hideDetails = true;

    /**
     * Método responsável por disparar a abertura da dialog
     */
    public openDialog() {
        this.poModal.open();
    }

    /**
     * Método responsável por fechar a dialog
     */
    public closeDialog() {
        this.poModal.close();
    }

    /**
     * Método responsável por executar ação do link relacionado a mensagem
     */
    public linkAction() {

        this.messageLinkAction();
    }
}
